"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getShopifyDate = exports.getFulfilledResults = exports.getThrottleResValues = exports.throttle = exports.formatIdForS3Names = exports.formartId = exports.getShopifyIdNumber = exports.multiplyCash = exports.getTotalTax = void 0;
const promises_1 = require("timers/promises");
function getTotalTax(taxLines) {
    return taxLines.reduce((prevValue, currentValue) => prevValue + parseFloat(currentValue.priceSet.presentmentMoney.amount), 0);
}
exports.getTotalTax = getTotalTax;
function multiplyCash(amount, multiplier) {
    return parseFloat(((parseInt(parseFloat(amount).toFixed(2).toString().replace(".", ""), 10) *
        multiplier) /
        100).toFixed(2));
}
exports.multiplyCash = multiplyCash;
function getShopifyIdNumber({ id, object }) {
    return parseInt(id.replace(`gid://shopify/${object}/`, ""), 10);
}
exports.getShopifyIdNumber = getShopifyIdNumber;
function formartId({ id, object }) {
    return `gid://shopify/${object}/${id}`;
}
exports.formartId = formartId;
function formatIdForS3Names(id) {
    return id.replaceAll("/", "-").replaceAll(":", "").replaceAll("--", "-");
}
exports.formatIdForS3Names = formatIdForS3Names;
async function throttle(req, reqInputList, limit = 4, wait = 2000) {
    const reqInput = [...reqInputList];
    const results = [];
    while (reqInput.length) {
        const tempInput = [];
        while (tempInput.length < limit + 1 && reqInput.length) {
            const val = reqInput.pop();
            if (val)
                tempInput.push(val);
        }
        const res2 = await Promise.allSettled(tempInput.map((input) => req(input)));
        results.push(...res2);
        if (wait === 0)
            continue;
        await (0, promises_1.setTimeout)(wait);
    }
    return results;
}
exports.throttle = throttle;
function getThrottleResValues(res) {
    return getFulfilledResults(res).map(({ value }) => value);
}
exports.getThrottleResValues = getThrottleResValues;
function getFulfilledResults(res) {
    return res.filter(({ status }) => status === "fulfilled");
}
exports.getFulfilledResults = getFulfilledResults;
function getShopifyDate(daysFromToday = 0) {
    const today = new Date();
    const date = new Date(new Date().setDate(today.getDate() + daysFromToday));
    return date.toISOString().split("T")[0];
}
exports.getShopifyDate = getShopifyDate;
